==> react-bootstrap-0.2.0.tgz: package/es/components/Input/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import Autocomplete from './Autocomplete';
import File from './File';
import Group from './Group';

import sizes from '../../utils/sizes';

var unstyledInputTypes = ['button', 'checkbox', 'file', 'hidden', 'image', 'radio', 'reset', 'submit', 'range'];

var Input = (_temp = _class = function (_Component) {
  _inherits(Input, _Component);

  function Input() {
    _classCallCheck(this, Input);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  Input.prototype.render = function render() {
    var _props = this.props,
        size = _props.size,
        className = _props.className,
        innerRef = _props.innerRef,
        props = _objectWithoutProperties(_props, ['size', 'className', 'innerRef']);

    return React.createElement('input', _extends({}, props, typeof innerRef === 'function' ? { ref: innerRef } : {}, {
      className: cn(!unstyledInputTypes.includes(props.type) && 'form-control form-control-' + size, className)
    }));
  };

  return Input;
}(Component), _class.defaultProps = {
  type: 'text',
  size: 'md',
  className: '',
  innerRef: null
}, _class.Autocomplete = Autocomplete, _class.File = File, _class.Group = Group, _temp);
Input.propTypes = process.env.NODE_ENV !== "production" ? {
  type: PropTypes.string,
  size: PropTypes.oneOf(sizes),
  className: PropTypes.string,
  innerRef: PropTypes.func
} : {};


export default Input;

==> react-bootstrap-0.3.0.tgz: package/es/components/Input/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import createComponent from '../../utils/createComponent';
import sizes from '../../utils/sizes';

import Autocomplete from './Autocomplete';
import File from './File';

var Group = createComponent('Input.Group', 'input-group');
var GroupPrepend = createComponent('Input.GroupPrepend', 'input-group-prepend');
var GroupAppend = createComponent('Input.GroupAppend', 'input-group-append');
var GroupText = createComponent('Input.GroupText', 'input-group-text');

var unstyledInputTypes = ['button', 'checkbox', 'file', 'hidden', 'image', 'radio', 'reset', 'submit', 'range'];

var Input = (_temp = _class = function (_Component) {
  _inherits(Input, _Component);

  function Input() {
    _classCallCheck(this, Input);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  Input.prototype.render = function render() {
    var _props = this.props,
        size = _props.size,
        innerRef = _props.innerRef,
        props = _objectWithoutProperties(_props, ['size', 'innerRef']);

    return React.createElement('input', _extends({}, props, typeof innerRef === 'function' ? { ref: innerRef } : {}, {
      className: cn(!unstyledInputTypes.includes(props.type) && 'form-control form-control-' + size, props.className)
    }));
  };

  return Input;
}(Component), _class.defaultProps = {
  type: 'text',
  size: 'md',
  innerRef: null
}, _class.Autocomplete = Autocomplete, _class.File = File, _class.Group = Group, _class.GroupPrepend = GroupPrepend, _class.GroupAppend = GroupAppend, _class.GroupText = GroupText, _temp);
Input.propTypes = process.env.NODE_ENV !== "production" ? {
  type: PropTypes.string,
  size: PropTypes.oneOf(sizes),
  innerRef: PropTypes.func
} : {};


export default Input;
